import Test.Hspec
import qualified WaiExtraTest

main :: IO ()
main = hspec WaiExtraTest.specs
